@@ -10,6 +10,7 @@ def default_cache_func(
         redis_model,
         save_related_models,
         get_or_create_redis_model_from_django_model,
+    exclude_fields,
 ):
 
     redis_dicts = redis_root.get(redis_model, return_dict=True)
@@ -24,6 +25,7 @@ def default_cache_func(
         redis_root,
         save_related_models,
         get_or_create_redis_model_from_django_model,
+    exclude_fields,
     )
 
 
@@ -163,6 +165,7 @@ def django_to_cache(
         redis_root,
         save_related_models,
         get_or_create_redis_model_from_django_model,
+        exclude_fields,
 ):
     async def run_django_to_cache(
             django_model,
@@ -170,6 +173,7 @@ def django_to_cache(
             redis_root,
             save_related_models,
             get_or_create_redis_model_from_django_model,
+            exclude_fields,
     ):
         django_instances = await django_sync_to_async_list(django_model.objects.all)
         async_chunk_size = redis_root.async_db_requests_limit
@@ -185,6 +189,7 @@ def django_to_cache(
                     redis_root,
                     save_related_models,
                     get_or_create_redis_model_from_django_model,
+                    exclude_fields,
                 )
             )
             completed += 1
@@ -201,6 +206,7 @@ def django_to_cache(
             redis_root,
             save_related_models,
             get_or_create_redis_model_from_django_model,
+            exclude_fields,
         )
     )
 
@@ -209,8 +215,9 @@ async def update_or_create_redis_instance_from_django_instance(
         django_instance,
         redis_model,
         redis_root,
-        get_or_create_redis_model_from_django_model,
         save_related_models,
+        get_or_create_redis_model_from_django_model,
+        exclude_fields,
 ):
     redis_instance = redis_root.get(redis_model, django_id=django_instance.id)
     redis_dict = await django_instance_to_redis_params(
@@ -218,6 +225,7 @@ async def update_or_create_redis_instance_from_django_instance(
         redis_root,
         save_related_models,
         get_or_create_redis_model_from_django_model,
+        exclude_fields,
     )
 
     if not redis_instance:
@@ -264,6 +272,7 @@ async def django_instance_field_to_redis_value(
         redis_root,
         save_related_models,
         get_or_create_redis_model_from_django_model,
+        exclude_fields,
 ):
     django_field_value = await django_sync_to_async_get(django_instance, django_field.name)
     redis_value = django_field_value
@@ -278,6 +287,7 @@ async def django_instance_field_to_redis_value(
                     redis_root,
                     save_related_models,
                     get_or_create_redis_model_from_django_model,
+                    exclude_fields,
                 )
                 redis_value = redis_foreign_key_instance
             else:
@@ -291,6 +301,7 @@ async def django_instance_field_to_redis_value(
                     redis_root,
                     save_related_models,
                     get_or_create_redis_model_from_django_model,
+                    exclude_fields,
                 )
                 for django_many_to_many_instance in django_many_to_many_instances
             ]
@@ -312,6 +323,7 @@ async def django_instance_to_redis_params(
         redis_root,
         save_related_models,
         get_or_create_redis_model_from_django_model,
+        exclude_fields,
 ):
     redis_params = {}
     for i, django_field in enumerate(django_instance.__class__._meta.get_fields()):
@@ -322,26 +334,34 @@ async def django_instance_to_redis_params(
                 redis_root,
                 save_related_models,
                 get_or_create_redis_model_from_django_model,
+                exclude_fields,
             )
             redis_params[django_field.name] = redis_param
     return redis_params
 
 
-def get_or_create_redis_instance_from_django_instance(
+async def get_or_create_redis_instance_from_django_instance(
         django_instance,
         redis_root,
         save_related_models,
         get_or_create_redis_model_from_django_model,
+        exclude_fields,
 ):
     django_instance_model = django_instance.__class__
-    redis_model = get_or_create_redis_model_from_django_model(django_instance_model, redis_root)
+    redis_model = get_or_create_redis_model_from_django_model(
+        django_instance_model,
+        redis_root,
+        save_related_models,
+        exclude_fields,
+    )
     redis_instance = redis_root.get(redis_model, django_id=django_instance.id)
     if not redis_instance:
-        redis_dict = django_instance_to_redis_params(
+        redis_dict = await django_instance_to_redis_params(
             django_instance,
             redis_root,
             save_related_models,
             get_or_create_redis_model_from_django_model,
+            exclude_fields,
         )
         redis_instance = redis_model(
             redis_root=redis_root,
