@@ -452,13 +452,17 @@ class RedisRoot:
 
     def check_cache(self):
         django_models_to_cache = self._get_django_models_to_cache()
+        exclude_fields = {
+            django_model: cache_conf['exclude_fields']
+            for django_model, cache_conf in django_models_to_cache.items()
+        }
         for django_model, cache_conf in django_models_to_cache.items():
             cache_func = cache_conf['cache_func']
             save_related_models = cache_conf['save_related_models']
             
-            def get_or_create_redis_model_from_django_model(django_model, redis_root, save_related_models):
+            def get_or_create_redis_model_from_django_model(django_model, redis_root, save_related_models, exclude_fields):
                 registered_models_names = [model.__name__ for model in redis_root.registered_models]
-                redis_fields = django_fields_to_redis_fields(django_model, redis_root, save_related_models)
+                redis_fields = django_fields_to_redis_fields(django_model, redis_root, save_related_models, exclude_fields)
                 if django_model.__name__ in registered_models_names:
                     existing_redis_model_index = registered_models_names.index(django_model.__name__)
                     existing_redis_model = redis_root.registered_models[existing_redis_model_index]
@@ -467,17 +471,21 @@ class RedisRoot:
                     new_redis_model = create_redis_model_from_redis_fields(django_model, redis_fields, redis_root)
                 return new_redis_model
             
-            def django_fields_to_redis_fields(django_model, redis_root, save_related_models):
+            def django_fields_to_redis_fields(django_model, redis_root, save_related_models, exclude_fields):
                 redis_fields = {}
                 for django_field in django_model._meta.get_fields():
                     django_field_name = django_field.name
-                    if django_field_name in ['id', 'pk']:
-                        django_field_name = 'django_id'
-                        redis_field = RedisNumber(null=False)
-                    else:
-                        redis_field = django_field_to_redis_field(django_field, redis_root, save_related_models)
-                    if redis_field:
-                        redis_fields[django_field_name] = redis_field
+                    allowed = True
+                    if django_model in exclude_fields.keys():
+                        allowed = (django_field_name not in exclude_fields[django_model])
+                    if allowed:
+                        if django_field_name in ['id', 'pk']:
+                            django_field_name = 'django_id'
+                            redis_field = RedisNumber(null=False)
+                        else:
+                            redis_field = django_field_to_redis_field(django_field, redis_root, save_related_models, exclude_fields)
+                        if redis_field:
+                            redis_fields[django_field_name] = redis_field
                 return redis_fields
 
             def create_redis_model_from_redis_fields(django_model, redis_fields, redis_root):
@@ -485,7 +493,7 @@ class RedisRoot:
                 redis_root.register_models([new_redis_model])
                 return new_redis_model
 
-            def django_field_to_redis_field(django_field, redis_root, save_related_models):
+            def django_field_to_redis_field(django_field, redis_root, save_related_models, exclude_fields):
 
                 field_mapping = {
                     django_models.BooleanField: RedisBool,
@@ -524,11 +532,11 @@ class RedisRoot:
                         {}
                     )
 
-                    redis_field_params = django_field_params_to_redis_field_params(django_field, redis_root, save_related_models)
+                    redis_field_params = django_field_params_to_redis_field_params(django_field, redis_root, save_related_models, exclude_fields)
                     redis_field = redis_field_class(**redis_field_params)
                 return redis_field
 
-            def django_field_params_to_redis_field_params(django_field, redis_root, save_related_models):
+            def django_field_params_to_redis_field_params(django_field, redis_root, save_related_models, exclude_fields):
                 allowed_params = ['null', 'default', 'choices', 'remote_field']
                 allowed_redis_params = {}
                 for django_field_param_name in django_field.__dict__.keys():
@@ -551,7 +559,7 @@ class RedisRoot:
                             if value is not None:
                                 value = value.model
                                 if value is not None:
-                                    value = get_or_create_redis_model_from_django_model(value, redis_root, save_related_models)
+                                    value = get_or_create_redis_model_from_django_model(value, redis_root, save_related_models, exclude_fields)
                                     if value is not None:
                                         allowed_redis_params[redis_field_param_name] = value
                                         allowed_redis_params['save_related_models'] = save_related_models
@@ -570,7 +578,7 @@ class RedisRoot:
                 redis_root.registered_models = new_registered_models
                 return new_redis_model
 
-            redis_model = get_or_create_redis_model_from_django_model(django_model, self, save_related_models)
+            redis_model = get_or_create_redis_model_from_django_model(django_model, self, save_related_models, exclude_fields)
 
             cache_func(
                 django_model,
@@ -578,6 +586,7 @@ class RedisRoot:
                 redis_model,
                 save_related_models,
                 get_or_create_redis_model_from_django_model,
+                exclude_fields,
             )
             print(f'Cached {django_model}')
 
@@ -619,6 +628,7 @@ class RedisRoot:
             'ttl': 60 * 5,
             'save_related_models': True,
             'cache_func': default_cache_func,
+            'exclude_fields': []
         }
         if user_cache_conf is not None:
             if type(user_cache_conf) == dict:
@@ -643,6 +653,17 @@ class RedisRoot:
                     else:
                         raise Exception(
                             f'{name} -> cache config -> cache_func must be callable function')
+                if 'exclude_fields' in user_cache_conf.keys():
+                    if type(user_cache_conf['exclude_fields']) == list:
+                        if all([
+                            (type(field) == str)
+                            for field in user_cache_conf['exclude_fields']
+                        ]):
+                            cache_conf['exclude_fields'] = user_cache_conf['exclude_fields']
+                        else:
+                            raise Exception(f'{name} -> cache config -> exclude_fields -> all fields must be strings')
+                    else:
+                        raise Exception(f'{name} -> cache config -> exclude_fields must be list')
             else:
                 raise Exception(f'{name} -> cache config must be dict')
 
